==> haskell-jose-0.6.0.3-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.6.0.3
id: jose-0.6.0.3-8F2xRoyHQCZHLBjRiGliBU
key: jose-0.6.0.3-8F2xRoyHQCZHLBjRiGliBU
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: af02e731697f6ff935868c84d771efb5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/jose-0.6.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/jose-0.6.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/jose-0.6.0.3
hs-libraries: HSjose-0.6.0.3-8F2xRoyHQCZHLBjRiGliBU
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    concise-0.1.0.0-F3DX3JMFymHIwc7a0rbYVD containers-0.5.10.2
    cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF
    monad-time-0.2-87TQCV3wNpH91r1vLr0r7Q
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP template-haskell-2.12.0.0
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    bytestring-0.10.8.2 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    time-1.8.0.2 network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    quickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi
    x509-1.7.2-GGwd2ufTO2hGHMdnUGdGxK
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             concise-0.1.0.0-F3DX3JMFymHIwc7a0rbYVD=371bacf42ed033e219682f2fd22cb18a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi=1928ece35e67ec41b499da4f70bba50f
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=4c821a304108f2b075d812c81435d53c
             monad-time-0.2-87TQCV3wNpH91r1vLr0r7Q=7f80b8def483b4402f78e5575f97629c
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             quickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi=69b5fbbff03492240fce36cfbd3ef83f
             x509-1.7.2-GGwd2ufTO2hGHMdnUGdGxK=39f4043fcaba78034ec90fcaccdf1c13
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.6.0.3-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.6.0.3
id: jose-0.6.0.3-GMK4t4sKQ3JvKVHD5w3SW
key: jose-0.6.0.3-GMK4t4sKQ3JvKVHD5w3SW
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: 217a73a973b01e951f0635ae18071edb
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/jose-0.6.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/jose-0.6.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/jose-0.6.0.3
hs-libraries: HSjose-0.6.0.3-GMK4t4sKQ3JvKVHD5w3SW
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    concise-0.1.0.0-F3DX3JMFymHIwc7a0rbYVD containers-0.5.10.2
    cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ
    monad-time-0.2-87TQCV3wNpH91r1vLr0r7Q
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP template-haskell-2.12.0.0
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    bytestring-0.10.8.2 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    time-1.8.0.2 network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    quickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi
    x509-1.7.2-HWwttPQbxT1IXnAe46vnpG
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             concise-0.1.0.0-F3DX3JMFymHIwc7a0rbYVD=371bacf42ed033e219682f2fd22cb18a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP=302f7d9b300167b44be1bfa67778ed25
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=66cafb37fc02a74908fd731801b55463
             monad-time-0.2-87TQCV3wNpH91r1vLr0r7Q=7f80b8def483b4402f78e5575f97629c
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             quickcheck-instances-0.3.16-LeXGXWc1Sov3fkkaL3Jmgi=69b5fbbff03492240fce36cfbd3ef83f
             x509-1.7.2-HWwttPQbxT1IXnAe46vnpG=0ff93dab81ca3c17acadf2a79f38f60f
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
